%global commit 7bef8f639e4d64a85a794e85fe3049dbb2acd32e
%global shortcommit %(c=%{commit}; echo ${c:0:7})

Name:           openni2
Version:        2.2.0.33
Release:        1%{?dist}
Summary:        Driver and libraries for OpenNI: The standard framework for 3D sensing

Group:          System Environment/Libraries
License:        ASL 2.0
URL:            http://www.openni.org/
Source0:        https://github.com/OpenNI/OpenNI2/archive/%{commit}/%{name}-%{version}-%{shortcommit}.tar.gz
Source1:        libopenni2.pc.in
Patch0:         openni2-fedora.patch
Patch1:         openni2-unbundle-libjpeg.patch
Patch2:         openni2-non-windows-doxyfile.patch

ExclusiveArch:  %{ix86} x86_64 %{arm}

BuildRequires:  python
BuildRequires:  libusbx-devel >= 1.0.8
BuildRequires:  freeglut-devel
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  chrpath
BuildRequires:  systemd-devel
BuildRequires:  libjpeg-turbo-devel
BuildRequires:  java
BuildRequires:  java-devel
BuildRequires:  jpackage-utils

%description
The OpenNI framework is an open source SDK used for the development of 3D
sensing middleware libraries and applications. The OpenNI website provides an
active community of developers, the tools and support, a network of potential
partners and a distribution platform - addressing the complete development
lifecycle.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package java
Summary:        Java library for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       java
Requires:       jpackage-utils

%description java
The %{name}-java package contains a Java JNI library for
developing applications that use %{name} in Java.

%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation
BuildArch:      noarch
Requires:       jpackage-utils

%description javadoc
The %{name}-javadoc package contains API documentatation for
%{name}-java

%package doc
Summary:        API documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description doc
The %{name}-doc package contains the automatically generated API documentation
for OpenNI2.

%package examples
Summary:        Sample programs for %{name}
Group:          Development/Tools
Requires:       %{name} = %{version}-%{release}

%description examples
The %{name}-examples package contains example programs for OpenNI2.

%prep
%setup -qn OpenNI2-%{commit}
%patch0 -p1 -b .fedora
%patch1 -p1 -b .unbundle-libjpeg
%patch2 -p1 -b .non-windows-doxygen

# Remove some bundled software
# This leaves only glh and XnLib
rm -rf ThirdParty/LibJPEG
rm -rf ThirdParty/GL/GL ThirdParty/GL/glut*
rm -rf ThirdParty/PSCommon/Testing
rm -rf ThirdParty/PSCommon/XnLib/ThirdParty

# Fix the java loadLibrary (per Fedora packaging spec)
sed -e 's![@]libdir[@]!%{_libdir}!g' \
    -e 's![@]name[@]!%{name}!g' \
    Wrappers/java/OpenNI.java/src/org/openni/NativeMethods.java -i

%build
# Make debug target so we get symbols -
# they will be extracted and put in debuginfo later
make %{?_smp_mflags} CFG=Debug all doc
%ifarch %{ix86}
%define psarch x86
%else
%ifarch x86_64
%define psarch x64
%else
%define psarch Arm
%endif
%endif
chrpath -d -k Bin/%{psarch}-Debug/* ||:

%install
mkdir -p %{buildroot}%{_includedir}/ni2
install -m0644 Include/*.h %{buildroot}%{_includedir}/ni2/
mkdir -p %{buildroot}%{_includedir}/ni2/Linux-Arm
install -m0644 Include/Linux-Arm/* %{buildroot}%{_includedir}/ni2/Linux-Arm/
mkdir -p %{buildroot}%{_includedir}/ni2/Linux-x86
install -m0644 Include/Linux-x86/* %{buildroot}%{_includedir}/ni2/Linux-x86/
mkdir -p %{buildroot}%{_includedir}/ni2/Driver
install -m0644 Include/Driver/* %{buildroot}%{_includedir}/ni2/Driver/

mkdir -p %{buildroot}%{_libdir}/%{name}
install -m0755 Bin/%{psarch}-Debug/libOpenNI2.jni.so %{buildroot}%{_libdir}/%{name}/libOpenNI2.jni.so
install -m0755 Bin/%{psarch}-Debug/libOpenNI2.so %{buildroot}%{_libdir}/libOpenNI2.so

mkdir -p %{buildroot}%{_libdir}/%{name}/Drivers
install -m0755 Bin/%{psarch}-Debug/OpenNI2/Drivers/libDummyDevice.so %{buildroot}%{_libdir}/%{name}/Drivers/libDummyDevice.so
install -m0755 Bin/%{psarch}-Debug/OpenNI2/Drivers/libOniFile.so %{buildroot}%{_libdir}/%{name}/Drivers/libOniFile.so
install -m0755 Bin/%{psarch}-Debug/OpenNI2/Drivers/libPS1080.so %{buildroot}%{_libdir}/%{name}/Drivers/libPS1080.so
install -m0755 Bin/%{psarch}-Debug/OpenNI2/Drivers/libPSLink.so %{buildroot}%{_libdir}/%{name}/Drivers/libPSLink.so

mkdir -p %{buildroot}%{_bindir}
%ifnarch %{arm}
install -m0755 Bin/%{psarch}-Debug/NiViewer %{buildroot}%{_bindir}/Ni2Viewer
install -m0755 Bin/%{psarch}-Debug/ClosestPointViewer %{buildroot}%{_bindir}/ClosestPointViewer
install -m0755 Bin/%{psarch}-Debug/SimpleViewer %{buildroot}%{_bindir}/SimpleViewer
install -m0755 Bin/%{psarch}-Debug/MultiDepthViewer %{buildroot}%{_bindir}/MultiDepthViewer
%endif
install -m0755 Bin/%{psarch}-Debug/PS1080Console %{buildroot}%{_bindir}/PS1080Console
install -m0755 Bin/%{psarch}-Debug/PSLinkConsole %{buildroot}%{_bindir}/PSLinkConsole
install -m0755 Bin/%{psarch}-Debug/EventBasedRead %{buildroot}%{_bindir}/EventBasedRead
install -m0755 Bin/%{psarch}-Debug/MultipleStreamRead %{buildroot}%{_bindir}/MultipleStreamRead
install -m0755 Bin/%{psarch}-Debug/MWClosestPointApp %{buildroot}%{_bindir}/MWClosestPointApp
install -m0755 Bin/%{psarch}-Debug/SimpleRead %{buildroot}%{_bindir}/SimpleRead

mkdir -p %{buildroot}%{_sysconfdir}/udev/rules.d/
install -m0644 Packaging/Linux/primesense-usb.rules %{buildroot}%{_sysconfdir}/udev/rules.d/557-primesense-usb.rules

mkdir -p %{buildroot}%{_datadir}/%{name}-doc
cp -Rp Source/Documentation/{html,Text} %{buildroot}%{_datadir}/%{name}-doc/

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -Rp Source/Documentation/java/* %{buildroot}%{_javadocdir}/%{name}/

mkdir -p %{buildroot}%{_jnidir}
install -m0644 Bin/%{psarch}-Debug/org.openni.jar %{buildroot}%{_jnidir}/%{name}.jar

mkdir -p %{buildroot}%{_libdir}/pkgconfig
sed -e 's![@]prefix[@]!%{_prefix}!g' \
    -e 's![@]exec_prefix[@]!%{_exec_prefix}!g' \
    -e 's![@]includedir[@]!%{_includedir}!g' \
    -e 's![@]libdir[@]!%{_libdir}!g' \
    -e 's![@]version[@]!%{version}!g' \
    %{SOURCE1} > %{buildroot}%{_libdir}/pkgconfig/libopenni2.pc

%files
%doc LICENSE NOTICE README ReleaseNotes.txt
%{_libdir}/libOpenNI2.so
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/Drivers
# NiViewer is not built for Arm
%ifnarch %{arm}
%{_bindir}/Ni2Viewer
%endif
%{_bindir}/PS1080Console
%{_bindir}/PSLinkConsole
%config(noreplace) %{_sysconfdir}/udev/rules.d/557-primesense-usb.rules

%files devel
%{_includedir}/ni2/
%{_libdir}/pkgconfig/libopenni2.pc

%files java
%{_libdir}/%{name}/libOpenNI2.jni.so
%{_jnidir}/%{name}.jar

%files javadoc
%{_javadocdir}/%{name}

%files doc
%{_datadir}/%{name}-doc

%files examples
%ifnarch %{arm}
%{_bindir}/ClosestPointViewer
%{_bindir}/SimpleViewer
%{_bindir}/MultiDepthViewer
%endif
%{_bindir}/EventBasedRead
%{_bindir}/MultipleStreamRead
%{_bindir}/MWClosestPointApp
%{_bindir}/SimpleRead

%changelog
* Mon Mar 03 2014 Scott K Logan <logans@cottsay.net> - 2.2.0.33-1
- Initial Package
